# kiirastuli

Purgatory (Finnish: kiirastuli) - purge like hell to stay out of trouble.

[License: MIT](https://git.sr.ht/~sthagen/kiirastuli/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![downloads](https://pepy.tech/badge/kiirastuli/month)](https://pepy.tech/project/kiirastuli)
[![wheel](https://img.shields.io/pypi/wheel/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![supported-versions](https://img.shields.io/pypi/pyversions/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)
[![supported-implementations](https://img.shields.io/pypi/implementation/kiirastuli.svg?style=flat)](https://pypi.python.org/pypi/kiirastuli/)

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of kiirastuli](https://todo.sr.ht/~sthagen/kiirastuli).

## Primary Source repository

The primary source of `kiirastuli` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `kiirastuli` are:

* [on codeberg](https://codeberg.org/sthagen/kiirastuli) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/kiirastuli) - a collection of tools useful for software development.
